@@ -116,17 +116,12 @@ class BOHB:
 
     def get_sample(self):
         if self.kde_good is None or np.random.random() < self.random_percent:
-            if self.samples.size:
-                # Return a random successful sample from the previous budget
-                return np.random.choice(self.samples)
-            else:
-                # Return a random configuration as there is no sample to choose from
-                return self.configspace.sample_configuration()
+            return self.configspace.sample_configuration()
 
         # Sample from the good data
+        best_tpe_val = np.inf
         for _ in range(self.n_samples):
             idx = np.random.randint(0, len(self.kde_good.configurations))
-            best_tpe_val = np.inf
             configuration = copy.deepcopy(self.kde_good.configurations[idx])
             for hyperparameter, bw in zip(configuration, self.kde_good.bw):
                 if hyperparameter.type == cs.Type.Continuous:
